##  Workspace Views Behavior
  * Default view: If an admin has defined a default workspace view for your user role, this view automatically applies when you first sign in to SAP LeanIX.
  * No views available: If you don't see the workspace views list on the right side of the navigation bar, it means an admin hasn't created any views for your user role.
  * Inactive views list: If the workspace views list is inactive, it means views are not available on the current page.
  * Multiple fact sheet types in views: If a view includes multiple fact sheet types and you apply it from the inventory, you're prompted to select a fact sheet type to get started. After making your selection, you can choose a different fact sheet type using inventory filters.
  * Saved searches: When you open a saved search in the inventory that contains fact sheet types not included in the selected workspace view, the view automatically switches to the full view. A message informs you about this change.


YesNo
Send
